@@ -4,7 +4,9 @@ Sample plugin file for highlight
 Adds a line to the left of the code box
 ]]
 
-Description="Adds a line to the left of the code box"
+Description="Adds a line to the left of the code box in HTML output"
+
+Categories = {"format", "html" }
 
 -- function to update theme definition
 -- optional parameter: theme description
